==> camel-k-model-v1-5.3.0-sources.jar: io/fabric8/camelk/v1/IntegrationPlatformFluentImpl.java <==
package io.fabric8.camelk.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class IntegrationPlatformFluentImpl<A extends IntegrationPlatformFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements IntegrationPlatformFluent<A> {

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private IntegrationPlatformSpecBuilder spec;
    private IntegrationPlatformStatusBuilder status;

    public IntegrationPlatformFluentImpl() {
    }

    public IntegrationPlatformFluentImpl(IntegrationPlatform instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(int[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(char[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(byte[] arg1,int arg2) {
        return (A)withApiVersion(new String(arg1, arg2));
    }

    public A withNewApiVersion(byte[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(char[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withApiVersion(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(int[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(char[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(byte[] arg1,int arg2) {
        return (A)withKind(new String(arg1, arg2));
    }

    public A withNewKind(byte[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(char[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withKind(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata) {
        _visitables.get("metadata").remove(this.metadata);
        if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public IntegrationPlatformFluent.MetadataNested<A> withNewMetadata() {
        return new MetadataNestedImpl();
    }

    public IntegrationPlatformFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
        return new MetadataNestedImpl(item);
    }

    public IntegrationPlatformFluent.MetadataNested<A> editMetadata() {
        return withNewMetadataLike(getMetadata());
    }

    public IntegrationPlatformFluent.MetadataNested<A> editOrNewMetadata() {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public IntegrationPlatformFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public IntegrationPlatformSpec getSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public IntegrationPlatformSpec buildSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(IntegrationPlatformSpec spec) {
        _visitables.get("spec").remove(this.spec);
        if (spec!=null){ this.spec= new IntegrationPlatformSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec() {
        return this.spec != null;
    }

    public IntegrationPlatformFluent.SpecNested<A> withNewSpec() {
        return new SpecNestedImpl();
    }

    public IntegrationPlatformFluent.SpecNested<A> withNewSpecLike(IntegrationPlatformSpec item) {
        return new SpecNestedImpl(item);
    }

    public IntegrationPlatformFluent.SpecNested<A> editSpec() {
        return withNewSpecLike(getSpec());
    }

    public IntegrationPlatformFluent.SpecNested<A> editOrNewSpec() {
        return withNewSpecLike(getSpec() != null ? getSpec(): new IntegrationPlatformSpecBuilder().build());
    }

    public IntegrationPlatformFluent.SpecNested<A> editOrNewSpecLike(IntegrationPlatformSpec item) {
        return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public IntegrationPlatformStatus getStatus() {
        return this.status!=null?this.status.build():null;
    }

    public IntegrationPlatformStatus buildStatus() {
        return this.status!=null?this.status.build():null;
    }

    public A withStatus(IntegrationPlatformStatus status) {
        _visitables.get("status").remove(this.status);
        if (status!=null){ this.status= new IntegrationPlatformStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus() {
        return this.status != null;
    }

    public IntegrationPlatformFluent.StatusNested<A> withNewStatus() {
        return new StatusNestedImpl();
    }

    public IntegrationPlatformFluent.StatusNested<A> withNewStatusLike(IntegrationPlatformStatus item) {
        return new StatusNestedImpl(item);
    }

    public IntegrationPlatformFluent.StatusNested<A> editStatus() {
        return withNewStatusLike(getStatus());
    }

    public IntegrationPlatformFluent.StatusNested<A> editOrNewStatus() {
        return withNewStatusLike(getStatus() != null ? getStatus(): new IntegrationPlatformStatusBuilder().build());
    }

    public IntegrationPlatformFluent.StatusNested<A> editOrNewStatusLike(IntegrationPlatformStatus item) {
        return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        IntegrationPlatformFluentImpl that = (IntegrationPlatformFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
        if (status != null ? !status.equals(that.status) :that.status != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
    }

    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<IntegrationPlatformFluent.MetadataNested<N>> implements IntegrationPlatformFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ObjectMetaBuilder builder;

            MetadataNestedImpl(ObjectMeta item) {
                this.builder = new ObjectMetaBuilder(this, item);
                        
            }

            MetadataNestedImpl() {
                this.builder = new ObjectMetaBuilder(this);
                        
            }

            public N and() {
                return (N) IntegrationPlatformFluentImpl.this.withMetadata(builder.build());
            }

            public N endMetadata() {
                return and();
            }
    }


    public class SpecNestedImpl<N> extends IntegrationPlatformSpecFluentImpl<IntegrationPlatformFluent.SpecNested<N>> implements IntegrationPlatformFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final IntegrationPlatformSpecBuilder builder;

            SpecNestedImpl(IntegrationPlatformSpec item) {
                this.builder = new IntegrationPlatformSpecBuilder(this, item);
                        
            }

            SpecNestedImpl() {
                this.builder = new IntegrationPlatformSpecBuilder(this);
                        
            }

            public N and() {
                return (N) IntegrationPlatformFluentImpl.this.withSpec(builder.build());
            }

            public N endSpec() {
                return and();
            }
    }


    public class StatusNestedImpl<N> extends IntegrationPlatformStatusFluentImpl<IntegrationPlatformFluent.StatusNested<N>> implements IntegrationPlatformFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final IntegrationPlatformStatusBuilder builder;

            StatusNestedImpl(IntegrationPlatformStatus item) {
                this.builder = new IntegrationPlatformStatusBuilder(this, item);
                        
            }

            StatusNestedImpl() {
                this.builder = new IntegrationPlatformStatusBuilder(this);
                        
            }

            public N and() {
                return (N) IntegrationPlatformFluentImpl.this.withStatus(builder.build());
            }

            public N endStatus() {
                return and();
            }
    }


}

==> camel-k-model-v1-5.3.1-sources.jar: io/fabric8/camelk/v1/IntegrationPlatformFluentImpl.java <==
package io.fabric8.camelk.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class IntegrationPlatformFluentImpl<A extends IntegrationPlatformFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements IntegrationPlatformFluent<A> {

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private IntegrationPlatformSpecBuilder spec;
    private IntegrationPlatformStatusBuilder status;

    public IntegrationPlatformFluentImpl() {
    }

    public IntegrationPlatformFluentImpl(IntegrationPlatform instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(int[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(char[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(byte[] arg1,int arg2) {
        return (A)withApiVersion(new String(arg1, arg2));
    }

    public A withNewApiVersion(byte[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(char[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withApiVersion(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(int[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(char[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(byte[] arg1,int arg2) {
        return (A)withKind(new String(arg1, arg2));
    }

    public A withNewKind(byte[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(char[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withKind(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata) {
        _visitables.get("metadata").remove(this.metadata);
        if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.MetadataNested<A> withNewMetadata() {
        return new MetadataNestedImpl();
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
        return new MetadataNestedImpl(item);
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.MetadataNested<A> editMetadata() {
        return withNewMetadataLike(getMetadata());
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.MetadataNested<A> editOrNewMetadata() {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public IntegrationPlatformSpec getSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public IntegrationPlatformSpec buildSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(IntegrationPlatformSpec spec) {
        _visitables.get("spec").remove(this.spec);
        if (spec!=null){ this.spec= new IntegrationPlatformSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec() {
        return this.spec != null;
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.SpecNested<A> withNewSpec() {
        return new SpecNestedImpl();
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.SpecNested<A> withNewSpecLike(IntegrationPlatformSpec item) {
        return new SpecNestedImpl(item);
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.SpecNested<A> editSpec() {
        return withNewSpecLike(getSpec());
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.SpecNested<A> editOrNewSpec() {
        return withNewSpecLike(getSpec() != null ? getSpec(): new IntegrationPlatformSpecBuilder().build());
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.SpecNested<A> editOrNewSpecLike(IntegrationPlatformSpec item) {
        return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public IntegrationPlatformStatus getStatus() {
        return this.status!=null?this.status.build():null;
    }

    public IntegrationPlatformStatus buildStatus() {
        return this.status!=null?this.status.build():null;
    }

    public A withStatus(IntegrationPlatformStatus status) {
        _visitables.get("status").remove(this.status);
        if (status!=null){ this.status= new IntegrationPlatformStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus() {
        return this.status != null;
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.StatusNested<A> withNewStatus() {
        return new StatusNestedImpl();
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.StatusNested<A> withNewStatusLike(IntegrationPlatformStatus item) {
        return new StatusNestedImpl(item);
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.StatusNested<A> editStatus() {
        return withNewStatusLike(getStatus());
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.StatusNested<A> editOrNewStatus() {
        return withNewStatusLike(getStatus() != null ? getStatus(): new IntegrationPlatformStatusBuilder().build());
    }

    public io.fabric8.camelk.v1.IntegrationPlatformFluent.StatusNested<A> editOrNewStatusLike(IntegrationPlatformStatus item) {
        return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        IntegrationPlatformFluentImpl that = (IntegrationPlatformFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
        if (status != null ? !status.equals(that.status) :that.status != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
    }

    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<io.fabric8.camelk.v1.IntegrationPlatformFluent.MetadataNested<N>> implements io.fabric8.camelk.v1.IntegrationPlatformFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ObjectMetaBuilder builder;

            MetadataNestedImpl(ObjectMeta item) {
                this.builder = new ObjectMetaBuilder(this, item);
                        
            }

            MetadataNestedImpl() {
                this.builder = new ObjectMetaBuilder(this);
                        
            }

            public N and() {
                return (N) IntegrationPlatformFluentImpl.this.withMetadata(builder.build());
            }

            public N endMetadata() {
                return and();
            }
    }


    public class SpecNestedImpl<N> extends IntegrationPlatformSpecFluentImpl<io.fabric8.camelk.v1.IntegrationPlatformFluent.SpecNested<N>> implements io.fabric8.camelk.v1.IntegrationPlatformFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final IntegrationPlatformSpecBuilder builder;

            SpecNestedImpl(IntegrationPlatformSpec item) {
                this.builder = new IntegrationPlatformSpecBuilder(this, item);
                        
            }

            SpecNestedImpl() {
                this.builder = new IntegrationPlatformSpecBuilder(this);
                        
            }

            public N and() {
                return (N) IntegrationPlatformFluentImpl.this.withSpec(builder.build());
            }

            public N endSpec() {
                return and();
            }
    }


    public class StatusNestedImpl<N> extends IntegrationPlatformStatusFluentImpl<io.fabric8.camelk.v1.IntegrationPlatformFluent.StatusNested<N>> implements io.fabric8.camelk.v1.IntegrationPlatformFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final IntegrationPlatformStatusBuilder builder;

            StatusNestedImpl(IntegrationPlatformStatus item) {
                this.builder = new IntegrationPlatformStatusBuilder(this, item);
                        
            }

            StatusNestedImpl() {
                this.builder = new IntegrationPlatformStatusBuilder(this);
                        
            }

            public N and() {
                return (N) IntegrationPlatformFluentImpl.this.withStatus(builder.build());
            }

            public N endStatus() {
                return and();
            }
    }


}
